//
//  lcd7seg.h
//
//  7-Sengent LCD Control
//  Copyright (C) 2011 Toyohiko Togashi tog001@nifty.com
//
//  This program is free software; you can redistribute it and/or modify it under the terms of the
//  GNU General Public License as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with this program.
//  If not, see <http://www.gnu.org/licenses/>
//
//
//	Description
//		7-Segment LCD control subroutine.
//		Supported any digits and order.
//
//  Device: PIC16F1939       IDE: MPLAB IDE 8.63, HI-TECH C Tools for the PIC10/12/16 MCU Family Version 9.81
//
//
//    Update history
//    ---------- ----- -------------------------------------------
//    2011.03.16 v0.0  1st rel (PIC16193X)
//


#ifndef LCD7SEG_H
#define LCD7SEG_H

//
//	Configure
//
#define LCD7SEG_COM_PIN		3				// Common pin (1~4)
#define LCD7SEG_SEG_PIN		23				// Segment pin (1~24)
#define LCD7SEG_DIG_WIDTH	10				// Physical column (1~)
#define LCD7SEG_INIT_PATT	0b00110110		// Initial display pattern
#define S(seg_pin, com_pin)	(com_pin * 24 + seg_pin)
#define LCD7SEG_SEGMAP		const unsigned char	lcd7seg_segmap[LCD7SEG_DIG_WIDTH][8] = {\
	{S( 0,3), S(13,1), S(13,0), S( 0,3), S( 0,3), S( 0,3), S( 0,3), S(13,2)},\
	{S(20,1), S( 7,1), S( 7,0), S( 7,2), S(14,2), S(14,0), S(12,1), S( 0,3)},\
	{S(21,1), S( 5,1), S( 5,0), S( 4,2), S(15,2), S(15,0), S( 4,1), S( 0,3)},\
	{S( 0,1), S( 0,0), S( 0,2), S(22,2), S(21,2), S(21,0), S(22,1), S( 0,3)},\
	{S( 1,1), S(19,1), S(19,0), S( 2,2), S(20,2), S(20,0), S( 2,1), S( 0,3)},\
	{S(18,1), S(17,0), S(17,2), S(18,2), S( 1,2), S( 1,0), S(18,0), S( 0,3)},\
	{S( 9,1), S( 6,0), S( 6,2), S( 9,2), S( 3,2), S( 3,0), S( 9,0), S(10,2)},\
	{S(11,1), S(16,0), S(16,2), S(11,2), S(10,0), S(10,1), S(11,0), S( 0,3)},\
	{S(16,1), S( 6,1), S( 3,1), S( 8,2), S( 8,0), S( 8,1), S(17,1), S( 0,3)},\
	{S(12,0), S(12,2), S(14,1), S(22,0), S( 0,3), S( 0,3), S( 0,3), S( 0,3)}\
} //    a        b        c        d        e        f        g        dp

//
//	API
//
extern void lcd7seg_Start(void);
extern void lcd7seg_PutPattern(unsigned char Pat, unsigned char Pos);
//     void lcd7seg_PutHex(unsigned char Hex, unsigned char Pos);
#define     lcd7seg_PutHex(Hex, Pos)	lcd7seg_PutPattern((lcd7seg_Pat[Hex]), (Pos))
extern void lcd7seg_DP(unsigned char Flag, unsigned char Pos);
extern void lcd7seg_Dim(signed char Dim);
extern void lcd7seg_DispInt(int Value, unsigned char Pos, signed char Len);
#define     lcd7seg_Refresh()
#define     lcd7seg_Update()
extern void lcd7seg_Stop(void);
// call sequense: led7seg_Start() -> ... -> led7seg_Stop()
// Pat:   Segment bit image(b7=dp b6=g b5=f ... b0=a)
// Pos:   Digit position(1~LED7SEG_DIG_WIDTH, 0=all digit)
// Hex:   Nibble data
// Flag:  Dot point flag(on=1 off=0)
// Dim:   Dimmer (bright=1 dark=0 little-dark=-1 more-dark=-2...)
// Value: Display number
// Pos:   Start digit position(1~LED7SEG_DIG_WIDTH)
// Len:   Display digit width

// Internal table
extern const  unsigned char lcd7seg_Pat[];

#endif